/** 
 * Copyright (C) 2009-2010 WIKI-SJ
 * License http://www.gnu.org/licenses/gpl.html GPL version 2 or higher
 * Authors Sébastien BADIA / Julien VAUBOURG to ASRALL Lic.
**/

Admin = {

	/** Implémentation de la fonction PHP du même nom */
	urlencode: function(text) {
		text = text.replace(/[ ]/g,'+');
		return escape(text);
	},

	/** Implémentation de la fonction PHP du même nom (supprime les blancs devant et derrière) */
	trim: function(text) {
		return text.replace(/^\s+/g,'').replace(/\s+$/g,'');
	},

	/** Remplace les tags bbcode par du html */
	replaceTags: function(text) {
		text = text.replace(/\*([^*]+)\*/g, '<strong>$1</strong>');
		text = text.replace(/\$([^$]+)\$/g, '<em>$1</em>');
		text = text.replace(/##([^#]+)##/g, '<h2>$1</h2>');
		text = text.replace(/#([^#]+)#/g, '<h1>$1</h1>');

		text = text.replace(/\[DIESE\]/g, '#');
		text = text.replace(/\[ALL\]/g, '*');
		text = text.replace(/\[DOL\]/g, '$');

		text = text.replace(/\[\[([^\|]+)\|([^\]]+)\]\]/g, '<a href="$2" class="externe" title="$2">$1</a>');
		text = text.replace(/\[([^\]]+)\]/g, '<a href="view.php?nom=$1">$1</a>');

		text = text.replace(/  /g, ' &nbsp;');
		text = text.replace(/\n/g, "<br />\n").replace(/\<\/h([0-9]+)\>\<br \/\>/g, "</h$1>");

		return text;
	},

	/** Remplace le HTML par les tags bbcode correspondant*/
	replaceHTML: function(text) {
		text = text.replace(/#/g, '[DIESE]');
		text = text.replace(/\*/g, '[ALL]');
		text = text.replace(/\$/g, '[DOL]');

		text = text.replace(/\<\/?h1\>/g, '#').replace(/\<\/?h2\>/g, '##');
		text = text.replace(/\<\/?strong\>/g, '*').replace(/\<\/?em\>/g, '$');
		text = text.replace(/\<br ?\/?\>/g, "");
		text = text.replace(/\<\/?strong\>/g, '*').replace(/\<\/?em\>/g, '$');

		text = text.replace(/\<a href="view\.php\?nom=[^"]+">([^<]+)\<\/a\>/g, '[$1]');
		text = text.replace(/\<a href="([^"]+)" class="externe" title="[^"]+">([^<]+)\<\/a\>/g, '[[$2|$1]]');

		text = text.replace(/&nbsp;/g, ' ');

		return text;
	},

	/** Edition d'un commentaire par l'admin (au double-click sur son texte).
	Remplace le texte du commentaire par un textarea le contenant. */
	editCommentaire: function(commentaire) {

		// Si le textarea n'apparait pas déjà
		if(commentaire.getElementsByTagName("textarea").length == 0) {
			var textarea = document.createElement("textarea");
			textarea.id = commentaire.id;

			// On remplace les bbcode par du HTML pour l'édition
			textarea.value = Admin.replaceHTML(Admin.trim(commentaire.innerHTML));

			// Lorsqu'on quitte le textarea, on réaffiche le commentaire sans le textarea
			textarea.onblur = function() {
				Admin.dispCommentaire(this);
			};

			// Lorsqu'on quitte le textarea alors que son contenu a changé depuis le focus,
			// on appelle la fonction de sauvegarde AJAX (puis sa fonction blur qui réaffichera
			// le commentaire normalement).
			textarea.onchange = function() {
				Admin.saveCommentaire(this);
			};

			// Remplacement du texte par le textarea, dans le document
			commentaire.innerHTML = "";
			commentaire.appendChild(textarea);

			// On donne le focus au textarea pour inviter à la modification et faire fermer l'édition
			// si on clique ailleurs (par onblur ou onchange).
			textarea.focus();
		}
	},

	/** Sauvegarde le contenu du textarea sur le serveur comme étant le nouveau texte du commentaire */
	saveCommentaire: function(texte) {
		var idCommentaire = texte.id.split("_")[1];

		// Enregistrement via AJAX
		Admin.xmlRequest(
			"editCommentaire.php",
			"idCommentaire=" + idCommentaire + "&texte=" + Admin.urlencode(texte.value)
		);

		// La fonction contenue dans le blur rétablira l'affichage du commentaire, avec le nouveau
		// contenu.
		texte.blur();
	},

	/** Interfaçage AJAX */
	xmlRequest: function(page, data) {
		var session = window.XMLHttpRequest ? new XMLHttpRequest() : (window.ActiveXObject ? new ActiveXObject("Microsoft.XMLHTTP") : null);

		session.open("POST", page, true);
		session.setRequestHeader("Content-type", "application/x-www-form-urlencoded");

		// Un bandeau <Patientez> est affiché en haut à gauche tant que l'enregistrement n'est pas effectué
		session.onreadystatechange = function() {
			if(session.readyState < 4)
				Admin.wait(true);

			if(session.readyState == 4)
				Admin.wait(false);
		};

		session.send(data);
	},

	/** Supprime le textarea créé à la volée pour l'édition du commentaire et le remplace par son contenu.
	<texte> correspondant au noeud textarea concerné. */
	dispCommentaire: function(texte) {
		var commentaireText = texte.value;
		var commentaireNode = texte.parentNode;

		// Suppression du textarea
		commentaireNode.removeChild(texte);

		// Affichage du commentaire, en prenant soin de remplacer le bbcode par du HTML
		commentaireNode.innerHTML = Admin.replaceTags(commentaireText);
	},

	/** Petit bandeau <Patientez> qui apparait ou disparait selon enable */
	wait: function(enable) {
		document.getElementById("wait").style.display = enable ? "block" : "none";
	},

	/** Aperçu en temps réel de la page lorsqu'on est sur la page d'édition.
	La fonction est appellée pour mettre à jour le contenu d'un div en fonction
	du contenu du textarea (en remplacant les bbcodes) à chaque ajout d'un caractère
	dans celui-ci (onkeyup). */
	apercu: function() {
		var divApercu = document.getElementById("apercu");
		var texte = document.getElementById("texteField");

		divApercu.innerHTML = Admin.replaceTags(texte.value);
	},

	dispApercu: function() {
		var divApercu = document.getElementById("apercu");

		if(!divApercu.style.display || divApercu.style.display == "none")
			Admin.appApercuFondant(0);
		else
			Admin.dispApercuFondant(90);
	},

	dispApercuFondant: function(indice) {
		var divApercu = document.getElementById("apercu");
		divApercu.style.opacity=(indice/100);

		var top = parseInt(divApercu.style.top);

		if(top > -200)
			divApercu.style.top = (top-16) + "px";

		if(indice > 0)
			setTimeout("Admin.dispApercuFondant(" + (indice-3) + ")", 3);
		else
			divApercu.style.display = "none";

	},

	appApercuFondant: function(indice) {
		var divApercu = document.getElementById("apercu");
		divApercu.style.opacity=(indice/100);

		var top = parseInt(divApercu.style.top);
		var top = divApercu.style.top ? parseInt(divApercu.style.top) : -200;

		divApercu.style.display = "block";

		if(top != 0)
			divApercu.style.top = (top+9 > 0) ? 0 : (top+9) + "px";

		if(indice < 90)
			setTimeout("Admin.appApercuFondant(" + (indice+4) + ")", 2);
	},

	/** Fonction d'ajout des tags bbcode autour d'un texte sélectionné dans un textarea.
	Utilisée via des boutons au dessus du textarea de la page d'édition.
	Fonction empruntée et modifiée depuis la page :
	http://www.editeurjavascript.com/scripts/scripts_formulaires_2_318.php */
	addTag: function(selec1, selec2) {
		var isMozilla = (navigator.userAgent.toLowerCase().indexOf('gecko')!=-1) ? true : false;
		var regexp = new RegExp("[\r]","gi");
		var oField = document.getElementById("texteField");

		if(isMozilla) {
			objectValue = oField.value;

			deb = oField.selectionStart;
			fin = oField.selectionEnd;

			objectValueDeb = objectValue.substring(0, oField.selectionStart);
			objectValueFin = objectValue.substring(oField.selectionEnd, oField.textLength);
			objectSelected = objectValue.substring(oField.selectionStart, oField.selectionEnd);

			oField.value = objectValueDeb + selec1 + objectSelected + selec2 + objectValueFin;
		} else {
			
			var str = document.selection.createRange().text;

			if(str.length > 0) {
				var sel = document.selection.createRange();
				sel.text = selec1 + str + selec2;
				sel.collapse();
				sel.select();

			} else {

				oField.focus(oField.caretPos);
				oField.focus(oField.value.length);
				oField.caretPos = document.selection.createRange().duplicate();
				
				var bidon = "%~%";
				var orig = oField.value;
				oField.caretPos.text = bidon;
				var i = oField.value.search(bidon);
				oField.value = orig.substr(0, i) + selec1 + selec2 + orig.substr(i, oField.value.length);
			}
		}

		// Force la mise à jour de l'aperçu
		oField.onkeyup();
	}
}
