<?php

/*
 * Copyright (C) 2010 Julien VAUBOURG / Sébastien BADIA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

class Column {

	// Tableau des paramétres de la colonne
	// (nom => valeur : dans ce cas uniquement name ou value
	// correspondant au nom et la valeur d'une colonne (champ) mysql
	private $parameters;

	/** Construction d'une colonne mysql, avec un nom, une valeur et un booléen indiquant
	si la valeur a changée depuis la dernière synchro. avec la valeur correspondante dans la BDD */
	public function __construct($name, $value = null) {
		$this->parameters = array("name" => $name, "value" => $value, "isToUpdate" => false);
	}

	public function __get($attribute) {
		return $this->parameters[$attribute];
	}

	public function __set($attribute, $value) {
		if($attribute == "value" && $this->value != $value)
			$this->parameters["isToUpdate"] = true;

		$this->parameters[$attribute] = $value;
	}

	public function __toString() {

		// Si la valeur correspondant à une colonne de date, on retourne la valeur formatée de la date
		// (JJ/MM/YY à HHhMM et SSs)
		if(substr($this->name, 0, 4) == "date" && !is_null($this->value))
			return truncDate($this->value);

		// Si c'est une colonne qui s'appelle texte, on remplace les bbcodes
		if($this->name == "texte" && !is_null($this->value) && PAGE != "edit")
			return replaceTags($this->value);

		// Concaténation avec une chaine vide pour transformer éventuellement null en string
		return $this->value."";
	}
}

?>
