<?php

/*
 * Copyright (C) 2010 Julien VAUBOURG / Sébastien BADIA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

class Commentaire extends ActiveRecord {

	// @Override
	/** Ajoute l'instanciation des clés étrangères, qui peut être désactivée (cas du new) */
	public function __construct($id, $initForeignKeys = true) {
		parent::__construct($id);

		// Initialisation si ça n'est pas l'id -1 ou pour l'ajout d'une ligne
		if($id > -1 && $initForeignKeys) {
			$this->auteur = new Auteur($this->auteur->value);
			$this->entree = new Entree($this->entree->value);
		}
	}

	// @Abstract
	/** Ajout d'une ligne dans la table et renvoie son instanciation */
	public static function add($idAuteur = null, $idEntree = null) {

		// Si aucun auteur n'est précisé, on attribue sa création à l'auteur connecté
		if(is_null($idAuteur)) {
			if(CONNECTED)
				$idAuteur = USER;
			else
				throw new Microsoft("L'ajout d'un Commentaire nécessite un id d'Auteur.");
		}

		// Création de l'enregistrement vide et instanciation
		$commentaire = new Commentaire(Commentaire::newRow(), false);

		if(is_null($idEntree))
			throw new Microsoft("Un commentaire doit appartenir à une Entree.");

		// Clés étrangères
		$commentaire->entree = new Entree($idEntree);
		$commentaire->auteur = new Auteur($idAuteur);

		return $commentaire;
	}

	// Formulaire HTML d'édition d'un commentaire (en réalité, juste ajout, puisque la modification se fait en AJAX */
	public function edit() {
		$tpl = $this->display("templates/commentaire_listItem_edit.tpl");
		$tpl = str_replace("<TPL:IDENTREE>", $this->entree->id, $tpl);

		return $tpl;
	}

	// @Override
	/** Renvoie une fausse instance de la table (n'ayant aucune donnée relative dans la base) */
	public static function fake() {
		$fake = parent::fake();

		$fake->entree = Entree::fake();
		$fake->auteur = Auteur::fake();

		return $fake;
	}

	// @Override
	/** Ajoute le formulaire d'ajout de commentaire à la liste des commentaires, si l'utilisateur est conncté */
	public static function toList($where = null) {
		$tpl = parent::toList($where);

		// Ajout des liens d'admin. lorsqu'ils lieu d'être (modification AJAX et suppression)
		$tpl = preg_replace("/\<TPL\:ADMIN_MOD\:([0-9]+)\>/", ADMIN ? ' id="com_\1" title="Double-cliquer pour éditer" ondblclick="Admin.editCommentaire(this)"' : null, $tpl);
		$tpl = preg_replace("/\<TPL\:ADMIN_SUP\:([0-9]+)\>/", ADMIN ? '(<a href="javascript:if(confirm(\'Etes-vous sûr de vouloir supprimer ce commentaire ?\')) window.location=\'delCommentaire.php?id=\1\'">Supprimer</a>)' : null, $tpl);

		if(CONNECTED) {

			// Récupére l'identifiant de l'entree concernée par la liste des commentaires */
			preg_match("/[[:alnum:]]+=([0-9]+)/", $where, $entree);
			$idEntree = $entree[1];

			// Création d'une fausse instance de commentaire, afin d'utiliser sa fonction d'édition
			$new = Commentaire::fake();

			// Initialisation des paramétres du fake
			$new->auteur = new Auteur(USER);
			$new->entree = new Entree($idEntree);
			$new->date->value = date("Y-m-d H:i:s");

			return str_replace("<TPL:AJOUT>", $new->edit(), $tpl);
		}

		return str_replace("<TPL:AJOUT>", null, $tpl);
	}
}

?>
