<?php

/*
 * Copyright (C) 2010 Julien VAUBOURG / Sébastien BADIA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

class Entree extends ActiveRecord {

	// @Override
	/** Ajout de l'instanciation de la clé étrangère, avec possibilité de la désactivé 
	(cas de l'id -1 ou pour l'ajout d'une ligne */
	public function __construct($id, $initForeignKeys = true) {
		parent::__construct($id);

		if($id > -1 && $initForeignKeys)
			$this->auteur = new Auteur($this->auteur->value);
	}

	// @Abstract
	/** Permet d'ajouter une ligne dans la table et de l'instancier, en renvoyant le pointeur */
	public static function add($idAuteur = null) {

		// Si aucun auteur n'est indiqué, on utilise l'utilisateur connecté
		if(is_null($idAuteur)) {
			if(CONNECTED)
				$idAuteur = USER;
			else
				throw new Microsoft("L'ajout d'une Entree nécessite un id d'Auteur.");
		}

		// Ajout d'une ligne dans la table et instanciationde cette ligne vide
		$entree = new Entree(Entree::newRow(), false);

		// Définition de la date de modification avec la date du jour
		$entree->datecreation->value = date("Y-m-d H:i:s");

		// Instanciation de la clé étrangère
		$entree->auteur = new Auteur($idAuteur);

		return $entree;
	}

	// @Override
	/** Instanciation d'une fausse instance, ajout de la fausse instanciation de la clé étrangère */
	public static function fake() {
		$fake = parent::fake();
		$fake->auteur = Auteur::fake();

		return $fake;
	}

	public function __toString() {
		$tpl = parent::__toString();

		// Remplacement du <nom> qui est affiché en urlencode
		preg_match('#view\.php\?nom=[^"]+"\>([^<]+)\</a\>#', $tpl, $nom);
		$tpl = str_replace($nom[1]."</a>", urldecode($nom[1])."</a>", $tpl);

		// Remplacement du lien de suppression de l'entrée, selon le statut de l'utilisaeur
		$tpl = str_replace("<TPL:ADMIN>", ADMIN ? " (<a href=\"javascript:if(confirm('Etes-vous sûr de vouloir supprimer cette page ?')) window.location='delEntree.php?id=$this->id'\" class=\"sup\">Sup</a>)" : null, $tpl);

		return $tpl;
	}
}

?>
