<?php

/*
 * Copyright (C) 2010 Julien VAUBOURG / Sébastien BADIA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

class Mysql {

	// Nb requetes
	private static $req = 0;

	// Instance PDO
	private static $pdo = null;

	// Unique instance de connexion MySQL
	private static $mypdo = null;

	// Paramétres de connexion MySQL
	private static $dns;
	private static $user;
	private static $password;

	/** Initialisation des paramétres de connexion MysQL
	(à appeller avant d'instancier le singleton) */
	public static function init($host, $dbname, $user, $pwd) {
		self::$dns = "mysql:host=$host;dbname=$dbname"; 
		self::$user = $user;
		self::$password = $pwd;
	}

	/** Création du singleton */
	private function __construct() {
		self::$pdo = new PDO(self::$dns, self::$user, self::$password);
		self::$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
	}

	/** Relais des fonctions PDO */
	public function __call($methodName, $methodArgs) {

		// Nombre de requetes stocke
		if($methodName == "query")
			self::$req++;

		if(method_exists(self::$pdo, $methodName))
			return call_user_func_array(array(self::$pdo, $methodName), $methodArgs);
		else
			throw new Exception("PDO: Methode $methodName absente");
	}

	/** Renvoie le pointeur vers le singleton */
	public static function get() {

		// Création du singleton si il n'existe pas encore
		if(is_null(self::$pdo))
			self::$mypdo = new Mysql();

		return self::$mypdo;
	}

	public function __destruct() {
		if(!is_null(self::$pdo))
			self::$pdo = null;

		echo "<!-- requetes : ".self::$req." -->";
	}
}
?>
