<?php

/*
 * Copyright (C) 2010 Julien VAUBOURG / Sébastien BADIA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

require_once("header.php");

try {
	if(!CONNECTED)
		throw new Microsoft("Vous devez être connecté pour créer une nouvelle page ou version.");

	// La page à éditer est accueil en absence de nom de page
	$nom = empty($_GET["nom"]) ? "accueil" : urlencode($_GET["nom"]);
	$page = $form = null;

	if(empty($nom))
		throw new Microsoft("Nom de page invalide.");

	try {
		// Identifiant de la page qui concerne l'entrée qui a la date de modification la plus récente
		// (dernière version de la page)
		$idLastVersion = Page::idLastVersion($nom);

		// Instanciation de cette dernière version
		$page = new Page($idLastVersion);

		// Récupération du formulaire d'édition de cette page
		$form = $page->edit();

		// Bouton de retour
		$form = str_replace('<TPL:RETOUR>', '<a href="view.php?nom='.urldecode($nom).'" class="bouton">&laquo; Retour</a>', $form);

	// Si une exception personnalisée a été lancée, c'est probablement que idLastVersion n'a trouvé aucune
	// page qui concerne cette potentielle entrée.
	} catch(Microsoft $e) {

		// On crée donc une fausse instance de page, afin de récupérer un formulaire d'édition
		// (et donc de création)
		$page = Page::fake();

		// Initialisation des valeurs qui vont créer la nouvelle entrée
		$page->entree->nom->value = htmlspecialchars($nom, ENT_NOQUOTES, "UTF-8");
		$page->datemodif->value = $page->entree->datecreation->value = date("Y-m-d H:i:s");
		$page->texte->value = "#".urldecode($page->entree->nom->value)."#";

		// Récupération du formulaire d'édition de la page,
		// qui créera une nouvelle page (et donc version, plus récente)
		$form = $page->edit();
		$form = str_replace('<TPL:RETOUR>', null, $form);
	}

	echo $form;

} catch(Microsoft $e) {
	echo $e;
}

require_once("footer.php");

?>
