<?php

/*
 * Copyright (C) 2010 Julien VAUBOURG / Sébastien BADIA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

ini_set("display_errors", 0);
date_default_timezone_set("Europe/Paris");

// L'installation n'a pas encore été effectuée, on redirige
if(!file_exists("config/.lock")) {
	header("Location: install/");
	exit();
}

header("Content-type: text/html; charset=UTF-8");
preg_match("#/([[:alnum:]_-]+)\.[a-z]{1,4}[^/]#i", $_SERVER["REQUEST_URI"], $url);

session_start();

function __autoload($className) {
	require_once("class/$className.class.php");
}

// Formatage d'un champ MySQL de type date (JJ:MM:AAAA HH:MM:SS) en format FR
function truncDate($datetime, $mode = 1) {
	list($date, $hours) = explode(" ", $datetime);
	list($year, $mon, $day) = explode("-", $date);

	switch($mode) {
		case 1 :
			return "<span title=\"$hours\">$day/$mon/$year</span>";

		case 2 :
		default :
			list($h, $m, $s) = explode(":", $hours); 
			return "$day/$mon/$year à ${h}h$m et ${s}s";
	}
}

// Transformation en HTML d'une ligne de résultat d'un retour de la fonction UNIX diff
function formatDiffLine($line) {
	switch(substr($line, 0, 1)) {

		// Une ligne a été supprimée
		case "<" :
			$line = preg_replace('/^<(.*)$/', '<div class="diff diff_del">$1</div>', $line);
		break;

		// Ajoutée
		case ">" :
			$line = preg_replace('/^>(.*)$/', '<div class="diff diff_add">$1</div>', $line);
		break;

		// Suppression des lignes intermédiaires (la lisibilité étant remplacée par les couleurs)
		case "-" :
		case "\\" :
			$line = null;
		break;

		// Libellé des changements (ajout, remplacement, ou suppression)
		default :
			$line = preg_replace('/^([0-9]+)a.*$/', '<div class="diff diff_sepchg">Ajout ligne $1</div>', $line);
			$line = preg_replace('/^([0-9]+,?[0-9]*)c.*$/', '<div class="diff diff_sepchg">Remplacement ligne(s) $1</div>', $line);
			$line = preg_replace('/^([0-9]+,?[0-9]*)d.*$/', '<div class="diff diff_sepchg">Suppression ligne(s) $1</div>', $line);
	}

	return $line;
}

// Remplace les tags bbcode par du HTML
function replaceTags($text) {
	$text = preg_replace('/\*([^*]+)\*/', '<strong>\1</strong>', $text);
	$text = preg_replace('/\$([^$]+)\$/', '<em>\1</em>', $text);
	$text = preg_replace('/##([^#]+)##/', '<h2>\1</h2>', $text);
	$text = preg_replace('/#([^#]+)#/', '<h1>\1</h1>', $text);

	$text = str_replace('[DIESE]', '#', $text);
	$text = str_replace('[ALL]', '*', $text);
	$text = str_replace('[DOL]', '$', $text);

	$text = preg_replace('/\[\[([^|]+)\|([^]]+)\]\]/', '<a href="\2" class="externe" title="\2">\1</a>', $text);
	$text = preg_replace('/\[([^]]+)\]/', '<a href="view.php?nom=\1">\1</a>', $text);

	$text = nl2br($text);
	$text = preg_replace('/\<\/h([0-9]+)\>\<br \/\>/', '</h\1>', $text);

	$text = str_replace('  ', ' &nbsp;', $text);

	return $text;
}

// Récupération du fichier de configuration XML
$config = file_get_contents("config/config.xml.php", 0, null, 16);
$config = simplexml_load_string($config, null, LIBXML_DTDVALID);

// Constantes du WIKI
define("CONNECTED", isset($_SESSION["user"]));
define("USER", CONNECTED ? $_SESSION["user"] : null);
define("ADMIN", CONNECTED && USER == 1);
define("PAGE", count($url) > 1 ? $url[1] : "index");
define("WIKI_NAME", $config->wiki);
define("TABLE_PREFIX", $config->db->prefix);

// Initiation des paramétres de connexion SQL
Mysql::init(
	$config->db->host,
	$config->db->dbname,

	// Seul l'admin se connecte avec un utilisateur MySQL ayant des droits tels que
	// la modification ou la suppression.
	ADMIN ? $config->db->admin->name : $config->db->user->name,
	ADMIN ? $config->db->admin->pwd : $config->db->user->pwd
);

// Suppression de la variable de config afin que les identifiants MySQL ne soient
// jamais accesssibles dans la suite du script.
unset($config);

// Début de la bufferisation : tout ce qui sera envoyé sur la sortie standard sera intercepté.
// Le contenu du buffer sera rattrapé dans footer.php
ob_start();

?>
