<?php

/*
 * Copyright (C) 2010 Julien VAUBOURG / Sébastien BADIA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

ini_set("display_errors", 0);
date_default_timezone_set("Europe/Paris");

// Si le fichier .lock existe c'est que l'installation a déjà été effectuée.
// On redirige donc vers la page index qui le dira mieux que nous.
if(file_exists("../config/.lock")) {
	header("Location: index.php");
	exit();
}

// Si un champ n'est pas remplis, on redirige
foreach($_POST AS $field) {
	if(empty($field)) {
		header("Location: index.php?emptyField");
		exit();
	}
}

if(!empty($_POST)) {

	// La licence n'a pas été acceptée
	if(empty($_POST["license_ok"])) {
		header("Location: index.php?license");
		exit();
	}

	// Si il y a nécessite d'avoir des droits de root (GRANT ou CREATE DATABASE)
	if(isset($_POST["create_user"]) || isset($_POST["create_admin"]) || isset($_POST["create_base"])) {
		try {
			// Connexion à mysql en tant que root
			$db = new PDO("mysql:host={$_POST["db_host"]}", $_POST["db_root_name"], $_POST["db_root_pwd1"]);
			$db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

			if(isset($_POST["create_base"])) {
				$req = "CREATE DATABASE IF NOT EXISTS {$_POST["db_dbname"]}";

				try {
					$db->query($req);
				} catch(PDOException $e) {
					exit("ERREUR: Impossible de créer la base avec l'utilisateur root indiqué.");
				}
			}

			if(isset($_POST["create_user"])) {
				$req = file_get_contents("sql/user.sql");

				$req = str_replace(
					Array("<DB:DBNAME>", "<DB:USER>", "<DB:HOST>", "<DB:PWD>"),
					Array($_POST["db_dbname"], $_POST["db_user_name"], $_POST["db_host"], $_POST["db_user_pwd1"]),
					$req);

				try {
					$db->query($req);
				} catch(PDOException $e) {
					exit("ERREUR: Impossible de créer l'utilisateur avec le compte root indiqué.");
				}
			}

			if(isset($_POST["create_admin"])) {
				$req = file_get_contents("sql/admin.sql");

				$req = str_replace(
					Array("<DB:DBNAME>", "<DB:USER>", "<DB:HOST>", "<DB:PWD>", "<DB:PREFIX>"),
					Array($_POST["db_dbname"], $_POST["db_admin_name"], $_POST["db_host"], $_POST["db_admin_pwd1"], $_POST["db_prefix"]),
					$req);

				try {
					$db->query($req);
				} catch(PDOException $e) {
					exit("ERREUR: Impossible de créer l'utilisateur admin avec le compte root indiqué.");
				}
			}

		} catch(PDOException $e) {
			exit("ERREUR: Impossible de se connecter en root.");
		}
	}

	try {
		// On se reconnecte ensuite à la base en tant qu'utilisateur admin. de la base, aux droits tout de même plus limités que root (et qu'on
		// a éventuellement créé ci-avant)
		$db = new PDO("mysql:host={$_POST["db_host"]};dbname={$_POST["db_dbname"]}", $_POST["db_admin_name"], $_POST["db_admin_pwd1"]);
		$db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

		$req = file_get_contents("sql/tables.sql");
		$req = str_replace("<DB:PREFIX>", $_POST["db_prefix"], $req);

		try {
			// Création des tables
			$db->query($req);
		} catch(PDOException $e) {
			exit("ERREUR: Impossible de créer les tables avec l'utilisateur admin (peut-être une table existe-t-elle déjà).");
		}

		try {
			// Ajout de l'utilisateur admin du wiki, qui aura donc l'id 1
			$db->query("
				INSERT INTO {$_POST["db_prefix"]}auteur(nom, prenom, pseudo, mail, mdp, valide)
				VALUES('".addslashes($_POST["wiki_admin_name"])."', '".addslashes($_POST["wiki_admin_fname"])."', '".addslashes($_POST["wiki_admin_pseudo"])."', '".addslashes($_POST["wiki_admin_mail"])."', '".md5($_POST["wiki_admin_pwd1"])."', NULL)
			");

			// Insertion de données d'exemple
			if(isset($_POST["samples"])) {
				$req = file_get_contents("sql/samples.sql");
				$req = str_replace("<DB:PREFIX>", $_POST["db_prefix"], $req);

				$db->query($req);
			}
		} catch(PDOException $e) {
			exit("ERREUR: Impossible d'insérer des données avec l'utilisateur admin.");
		}

		file_put_contents("../config/.lock", null);

	} catch(PDOException $e) {
		exit("ERREUR: Impossible de se connecter avec l'utilisateur admin.");
	}

	// Headers du XML qui sera créé pour stocker des informations sur la configuration du wiki
	$xml_config = simplexml_load_string(
		"<?xml version='1.0' encoding='UTF-8' standalone='no'?>\n".
		"<!DOCTYPE config SYSTEM 'config/config.dtd'>\n".
		"<config></config>");

	/* <config>
		<wiki>xxxx</wiki>
		<db>
			<host>xxxx</host>
			<dbname>xxxx</dbname>
			<prefix>xxxx</prefix>
			<user>
				<name>xxxx</name>
				<pwd>xxxx</pwd>
			</user>
			<admin>
				<name>xxxx</name>
				<pwd>xxxx</pwd>
			</admin>
		</db>
	</config> */

	$xml_config->addChild("wiki", $_POST["wiki_name"]);

		$xml_db = $xml_config->addChild("db");
		$xml_db->addChild("host", $_POST["db_host"]);
		$xml_db->addChild("dbname", $_POST["db_dbname"]);
		$xml_db->addChild("prefix", $_POST["db_prefix"]);

			$xml_user = $xml_db->addChild("user");
			$xml_user->addChild("name", $_POST["db_user_name"]);
			$xml_user->addChild("pwd", $_POST["db_user_pwd1"]);

			$xml_admin = $xml_db->addChild("admin");
			$xml_admin->addChild("name", $_POST["db_admin_name"]);
			$xml_admin->addChild("pwd", $_POST["db_admin_pwd1"]);

	// Ecriture du XML, avec une ligne PHP évitant la lecture directe des données
	file_put_contents(
		"../config/config.xml.php",
		"<?php exit() ?>\n".$xml_config->asXML()
	);

	header("Location: ../index.php");	
}

?>
