<?php

/*
 * Copyright (C) 2010 Julien VAUBOURG / Sébastien BADIA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

require_once("header.php");

/** Gestion du login verification, compte bien activé **/
function login() {
	$idAuteur = Auteur::whatId($_POST["admin_user"]);
	$utilisateur = new Auteur($idAuteur);

	if(empty($utilisateur->valide)) {
		checkBDD();
	}
	else {
		throw new Microsoft("Ce compte n'a pas encore été validé...");
	}
}

/** Affichage du template formulaire d'enregistrement **/
function formulaire() {
	echo file_get_contents('./templates/registration.tpl');
}

/** Affichage du template en cours d'activation **/
function enCours() {
	echo file_get_contents('./templates/registration_encours.tpl');
}

/** Enregistrement d'un utilisateur **/
function enregistrement() {
	if(isset($_POST["check"])) {
		// Verification si champs vides sinon exeception
		if($_POST["nom"]=="" || $_POST["prenom"]=="" || $_POST["mail"]=="" || $_POST["login"]=="" || $_POST["pwd"]=="" || $_POST["pwd2"]=="" ){
			throw new Microsoft("Veuillez remplir tous les champs !");
		}
		else {
			// Verification que les mdp sont identiques
			if($_POST["pwd"] == $_POST["pwd2"]) {
				saveToBDD();
			}
			else {
				throw new Microsoft("Les deux mots de passe ne correspondent pas !");
			}
		}
	}
	else {
		formulaire();
	}
}

/** Verification dans la base des infos de connexion **/
function checkBDD() {
	
	$md5=md5($_POST["admin_pwd"]);
	
	// Determiner l'id de l'utilisateur grâce à la classe Auteur
	$idAuteur = Auteur::whatId($_POST["admin_user"]);
	if(empty($idAuteur)) {
		throw new Microsoft("Nous ne vous connaissons pas, utilisateur inconnu!");
	}
	else {
		// si un id retourné alors on test le couple login/mdp donné
		$utilisateur = new Auteur($idAuteur);
		
		if($utilisateur->pseudo==$_POST["admin_user"] && $utilisateur->mdp==$md5 ){
			// puis initialisation de la variable de session
			$_SESSION["user"]=$idAuteur;
			header("Location:index.php");
		}
		else {
			throw new Microsoft("Le mot de passe de correspond pas à ce compte !");
		}
	}
}   

/** Enregistrement dans la base de donnée d'un nouvel utilisateur **/
function saveToBDD() {
	$idAuteur = Auteur::whatId($_POST["login"]);

	// si l'id existe déja on ne l'enregistre pas...
	if(!empty($idAuteur)) {
		throw new Microsoft("Vous existez déja dans notre base de données !");
	}
	else{
		$pass=md5($_POST["pwd"]);
			
		# envoi du lien d'activation par un mail en html

		// Calcul d'un md5 sur le prénom pour servir de clé de validation
		$cle = md5(mt_rand());
		
		$headers = "From: ".WIKI_NAME." <wiki-sj@yopmail.com>";

		$message = "Bonjour {$_POST["prenom"]}.\n\n";
		$message .= "Pour valider votre compte, veuillez vous rendre sur la page suivante :\n";
		$message .= "http://{$_SERVER["HTTP_HOST"]}{$_SERVER["SCRIPT_NAME"]}?action=confirm&login={$_POST["login"]}&cle=$cle\n\n";
		$message .= "A bientôt sur ".WIKI_NAME;
		
		# création de l'auteur (attente de validation)
		$newAuteur = Auteur::add();
		$newAuteur->nom->value=$_POST["nom"];
		$newAuteur->prenom->value=$_POST["prenom"];
		$newAuteur->pseudo->value=$_POST["login"];
		$newAuteur->mail->value=$_POST["mail"];
		$newAuteur->mdp->value=$pass;
		$newAuteur->valide->value=$cle;

		// Sécurité anti-injection de headers
		$mail = explode(";", $_POST["mail"]);

		if(mail(htmlentities($mail[0]), "Validation", $message, $headers)) {
			enCours();
		} 
		else {
			throw new Microsoft("L'email de validation n'a pas pu être envoyé.");
		}
	}
}

/** Activation du compte passé dans le fomulaire de validation **/
function validation() {
	$id = Auteur::whatId($_GET["login"]);
	$user = new Auteur($id);

	$cleval = $_GET["cle"]; //la clé du lien
	$cleaut = $user->valide;

	if ($cleaut == $cleval) {
		$user->valide->value=NULL;
		validee();
	}
	else {
		if(empty($cleaut)) {
			throw new Microsoft("Ce compte est déjà activé !");
		}
		else {
			throw new Microsoft("La clé ne correspond pas à votre compte !");
		}
	}
}

/** Affichage du template compte validé**/
function validee() {
	$file = file_get_contents('./templates/registration_comptevalide.tpl');
	echo $file;
}


/** Switch case en fonction de la variable action en get **/
try {
	switch($_GET["action"]){
	
		case "rec":
			enregistrement();
			break;
	
		case "log":
			login();
			break;
	
		case "form":
			formulaire();
			break;
		
		case "confirm":
			validation();
			break;
	
		case "deco":
			session_destroy();

		default:
			header("Location: view.php");
	}
} catch(Microsoft $e) {
	echo $e;
}
 
require_once("footer.php");

?>
